/**
 * 检测项目
* @property {number} id - 主键ID
 * @property {number|null} obrId - 就诊id
 * @property {string|null} serialNo - 序号
 * @property {string|null} dataType - 数据类型
 * @property {string|null} mecTechObsProject - 医技观察项目
 * @property {string|null} mecTechObsName - 医技项目名称
 * @property {string|null} obsProjectDetail - 观察子项
 * @property {string|null} projectInfo - 项目结果信息
 * @property {string|null} unitCode - 项目单位 单位代码
 * @property {string|null} unitName - 项目单位 单位名称
 * @property {string|null} result - 结果参考值
 * @property {string|null} sign - 高低标志
 * @property {string|null} obsClassification - 微生物观察分类
 * @property {string|null} testMethod - 检验方法
 * @property {number|null} patientId - 患者ID
 */
export interface Obx {
  id: number;
  obrId?: number;
  serialNo?: string;
  dataType?: string;
  mecTechObsProject?: string;
  mecTechObsName?: string;
  obsProjectDetail?: string;
  projectInfo?: string;
  unitCode?: string;
  unitName?: string;
  result?: string;
  sign?: string;
  obsClassification?: string;
  testMethod?: string;
  patientId?: number;
}

export type ObxList = Obx[];

export interface Patient {
  patId?: string;
  cardId?: string;
  pvId?: string,
  department: string,
  physician: string,
  name: string,
  dischargeMethod?: string,
  dischargeTime?: string,
}

export type PatientList = Patient[]

/**
 * 每个检查项目（obx）的详细检测报告
 * @property {number} id - 主键ID
 * @property {string|null} cardId - 就诊卡号
 * @property {number|null} ordersId - 医嘱ID
 * @property {string|null} medOrderCode - 医嘱明细序号
 * @property {string} reportNo - 报告单号
 * @property {string|null} medOrderNo - 医技号
 * @property {string|null} medTechProInfo - 医技项目代码
 * @property {string|null} medTechProName - 医技项目名称
 * @property {string|null} reportClass - 报告单类别名称
 * @property {string|null} reportStatus - 危机报告标志
 * @property {string|null} examinePart - 检查部位或样本名称
 * @property {string|null} appEmployeeId - 申请医生代码
 * @property {string|null} appEmployeeName - 申请医生姓名
 * @property {string|null} appDeptCode - 申请科室代码
 * @property {string|null} appDeptName - 申请科室名称
 * @property {string|null} executeDeptCode - 执行科室代码
 * @property {string|null} executeDeptName - 执行科室名称
 * @property {string|null} medOrderAppTime - 医嘱申请时间
 * @property {string|null} chkStartTime - 检验或检查开始时间
 * @property {string|null} releaseTime - 发布时间
 * @property {string|null} repTypeCode - 报告单类别编码
 * @property {string|null} resultFlag - 结果标志
 * @property {string|null} repType - 报告类型
 * @property {string|null} checkEmployeeId - 报告审核Id
 * @property {string|null} checkEmployeeName - 报告审核者
 * @property {string|null} checkTime - 审核日期
 * @property {string|null} publisherEmployeeId - 报告发布者id
 * @property {string|null} publisherEmployeeName - 报告发布者
 * @property {string|null} publisherTime - 发布时间
 * @property {string|null} reportEntryId - 报告录入人ID
 * @property {string|null} reportEntryName - 报告录入人名称
 * @property {string|null} enterTime - 报告单日期
 * @property {string|null} bookingNo - 预约单号
 * @property {number|null} patientId - 患者ID
 */
export interface Obr {
  applicationNo: null;
  orderCode: null;
  id: number;
  cardId?: string;
  ordersId?: number;
  medOrderCode?: string;
  reportNo: string;
  medOrderNo?: string;
  medTechProInfo?: string;
  medTechProName?: string;
  reportClass?: string;
  medOrderAppTime?: string;
  chkStartTime?: string;
  reportStatus?: string;
  examinePart?: string;
  appEmployeeId?: string;
  appEmployeeName?: string;
  appDeptCode?: string;
  appDeptName?: string;
  executeDeptCode?: string;
  executeDeptName?: string;
  releaseTime?: string;
  repTypeCode?: string;
  resultFlag?: string;
  repType?: string;
  checkEmployeeId?: string;
  checkEmployeeName?: string;
  checkTime?: string;
  publisherEmployeeId?: string;
  publisherEmployeeName?: string;
  publisherTime?: string;
  reportEntryId?: string;
  reportEntryName?: string;
  enterTime?: string;
  bookingNo?: string;
  patientId?: number;
}

export type ObrList = Obr[];
