package com.ruoyi.web.work.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.web.work.api.util.AppUtil;
import com.ruoyi.web.work.domain.FollowRecord;
import com.ruoyi.web.work.domain.dto.FollowRecordDto;
import com.ruoyi.web.work.domain.dto.VisitDto;
import com.ruoyi.web.work.domain.vo.VisitVoList;
import com.ruoyi.web.work.mapper.FollowRecordMapper;
import com.ruoyi.web.work.service.IFollowRecordService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * @author lsw
 * @date 2024-07-18
 */
@Service
public class FollowRecordServiceImpl extends ServiceImpl<FollowRecordMapper, FollowRecord> implements IFollowRecordService {
    @Autowired
    private FollowRecordMapper followRecordMapper;

    @DataScope(deptAlias = "k")
    @Override
    public List<FollowRecord> selectList(FollowRecord followRecord) {
        return followRecordMapper.selectList(followRecord);
    }

    @Override
    public AjaxResult detail(Long id) {
        FollowRecord followRecord = getById(id);
        if (followRecord == null || !followRecord.getPatientId().equals(AppUtil.getUser().getPatientId())) {
            return AjaxResult.error("回访不存在或非法操作");
        }
        return AjaxResult.success(followRecord);
    }

    @Override
    public AjaxResult push(FollowRecordDto dto) {
        FollowRecord followRecord = getById(dto.getId());
        if (followRecord == null || !followRecord.getPatientId().equals(AppUtil.getUser().getPatientId())) {
            return AjaxResult.error("回访不存在或非法操作");
        }
        followRecord.setOp(dto.getOp());
        followRecord.setState(1);
        if (!updateById(followRecord)) {
            throw new ServiceException("提交回访记录失败");
        }
        return AjaxResult.success();
    }

    @Override
    public List<VisitVoList> selectVisitList(VisitDto dto) {
        return followRecordMapper.selectVisitList(dto);
    }

    @Override
    public List<FollowRecord> selectAppList(FollowRecord followRecord) {
        return followRecordMapper.selectAppList(followRecord);
    }

    @Override
    public AjaxResult add(FollowRecord followRecord) {
        if (followRecord.getPatientList().size() == 0) {
            return AjaxResult.error("请选择推送的患者");
        }
        List<FollowRecord> followRecordList = new ArrayList<>();
        followRecord.getPatientList().forEach(e -> {
            FollowRecord record = new FollowRecord();
            record.setType(followRecord.getType());
            record.setTemplateName(followRecord.getTemplateName());
            record.setOp(followRecord.getOp());
            record.setPatientId(e.getId());
            record.setPatientName(e.getName());
            followRecordList.add(record);
        });
        if (!saveBatch(followRecordList)) {
            throw new ServiceException("新增回访记录失败");
        }
        return AjaxResult.success();
    }
}
